<?php

/**
 * Registers the `gtm/decorated-list` block on the server.
 */
function gtm_register_block_decorated_list() {
	gtm_register_block_type( 'decorated-list' );
}

add_action( 'init', 'gtm_register_block_decorated_list', 20 );

add_filter( 'gtm.BlockStyleCompiler.gtm/decorated-list', 'gtm_compile_block_css_decorated_list', 10, 3 );
function gtm_compile_block_css_decorated_list( $output, $attributes, $blockName ) {
	$block_style = ['classes' => [], 'style' => []];

	$block_style['classes'][] = 'gtm-block';
	$block_style['classes'][] = "gtm-has-list-bullet-type-{$attributes['bulletType']}";

	if ( $attributes['icon'] ) {
		$block_style['classes'][] = "gtm-has-list-icon-{$attributes['icon']}";
	}

	if ( $attributes['enableTimeline'] ) {
		$block_style['classes'][] = "gtm-has-list-timeline";
	}

	gtm_css_compileCssVar( $block_style, "list-spacing", gtm_css_parseSpacingValue( $attributes['listSpacing'] ) );

	gtm_css_compileCssVar( $block_style, "list-bullet-width", $attributes['bulletWidth'] );

	gtm_css_compileCssVar( $block_style, "list-bullet-spacing", gtm_css_parseSpacingValue( $attributes['bulletSpacing'] ) );

	gtm_css_compileCssVar( $block_style, "list-bullet-radius", gtm_css_parseBorderRadiusValue( $attributes['bulletRadius'] ) );

	gtm_css_compileCssVar( $block_style, "list-bullet-color", gtm_css_parseColorValue( $attributes['bulletColor'] ) );

	gtm_css_compileCssVar( $block_style, "list-bullet-bg", gtm_css_parseColorValue( $attributes['bulletBg'] ) );

	if ( 'numbers' == $attributes['bulletType'] ) {
		gtm_css_compileCssVar( $block_style, "list-number-start", $attributes['numberStart'] );
	}

	if ( $attributes['enableTimeline'] ) {
		gtm_css_compileCssVar( $block_style, "list-timeline-color", gtm_css_parseColorValue( $attributes['timelineColor'] ) );

		if ( $attributes['timelineOpacity'] ?? null ) {
			gtm_css_compileCssVar( $block_style, "list-timeline-opacity", intval( $attributes['timelineOpacity'] ) / 100 );
		}

		gtm_css_compileCssVar( $block_style, "list-timeline-thickness", $attributes['timelineThickness'] );
	}

	// Apply to output
	$block_style['style'] = ['{{BLOCK}}' => $block_style['style']];

	return [
		'classes' => array_merge( $output['classes'], $block_style['classes'] ),
		'style'   => array_replace_recursive( $output['style'], $block_style['style'] ),
	];
}
