<?php

function gtm_render_block_icon_link( $attr, $content, $block ) {
	// Filtering url by variations
	if ( 'woo-account' == $attr['type'] && gtm_has_woocommerce() ) {
		if ( is_user_logged_in() || empty( $attr['url'] ) ) {
			$attr['url'] = get_permalink( get_option( 'woocommerce_myaccount_page_id' ) );
		}
	}

	$open_in_new_tab = $attr['openInNewTab'] ?? false;
	$is_anchor_link  = preg_match( '|^#|', $attr['url'] );

	$rel_target_attributes = '';
	if ( $open_in_new_tab && ! $is_anchor_link ) {
		$rel_target_attributes = 'rel="noopener nofollow" target="_blank"';
	}

	$icon = 'gtm-basic-icon-link';
	if ( ! empty( $attr['icon'] ) ) {
		$icon = $attr['icon'];
	}

	$wrapper_attr = ['class' => ''];
	if ( ! empty( $attr['type'] ) ) {
		$wrapper_attr['data-type'] = $attr['type'];
	}

	$wrapper_attributes = get_block_wrapper_attributes( $wrapper_attr );

	$inner_html = '';
	$inner_html .= sprintf( '<a class="wp-block-gtm-icon-link__link" href="%s" aria-label="%s" %s>', esc_url( $attr['url'] ), esc_attr( $attr['label'] ), $rel_target_attributes );
	$inner_html .= sprintf( '<i class="gtm-icon %s"></i>', esc_attr( $icon ) );
	$inner_html .= '</a>';

	return sprintf(
		'<div %1$s>%2$s</div>',
		$wrapper_attributes,
		$inner_html
	);
}

/**
 * Registers the `gtm/icon-link` block on the server.
 */
function gtm_register_block_icon_link() {
	gtm_register_block_type( 'icon-link', [
		'render_callback' => 'gtm_render_block_icon_link',
	] );
}

add_action( 'init', 'gtm_register_block_icon_link', 20 );

add_filter( 'gtm.BlockStyleCompiler.gtm/icon-link', 'gtm_compile_block_css_icon_link', 10, 3 );
function gtm_compile_block_css_icon_link( $output, $attributes, $blockName ) {
	$block_style = ['classes' => [], 'style' => []];

	$block_style['classes'][] = 'gtm-block';

	gtm_css_compileCssVar( $block_style, "icon-link-icon-size", $attributes['iconSize'] );

	/* Colors */

	gtm_css_compileCssVar( $block_style, "icon-link-color", gtm_css_parseColorValue( $attributes['color'] ) );
	gtm_css_compileCssVar( $block_style, "icon-link-bg", gtm_css_parseColorValue( $attributes['bg'] ) );
	gtm_css_compileCssVar( $block_style, "icon-link-hover-color", gtm_css_parseColorValue( $attributes['hoverColor'] ) );
	gtm_css_compileCssVar( $block_style, "icon-link-hover-bg", gtm_css_parseColorValue( $attributes['hoverBg'] ) );

	// Apply to output
	$block_style['style'] = ['{{BLOCK}}' => $block_style['style']];

	return [
		'classes' => array_merge( $output['classes'], $block_style['classes'] ),
		'style'   => array_replace_recursive( $output['style'], $block_style['style'] ),
	];
}
