<?php

/**
 * Renders the `gtm/post-author` block on the server.
 *
 * @param array    $attributes Block attributes.
 * @param string   $content    Block default content.
 * @param WP_Block $block      Block instance.
 * @return string Returns the post author for the current post.
 */
function gtm_render_block_post_author( $attr, $content, $block ) {

	if ( ! isset( $block->context['postId'] ) ) {
		return '';
	}

	$post_ID            = $block->context['postId'];
	$author_id          = get_post_field( 'post_author', $block->context['postId'] );
	$author_name        = get_the_author_meta( 'display_name', $author_id );
	$wrapper_attributes = get_block_wrapper_attributes( ['class' => ''] );

	$inner_html = '';
	if ( $attr['display'] == 'avatar' ) {
		$inner_html .= get_avatar( $author_id, intval( $attr['avatarSize'] ) );
	}

	if ( $attr['display'] == 'icon' ) {
		$inner_html .= gtm_icon( ! empty( $attr['icon'] ) ? $attr['icon'] : 'author' );
	}

	if ( empty( $attr['enableLink'] ) ) {
		$inner_html .= '<span>' . $author_name . '</span>';

	} else {
		$inner_html .= sprintf( '<a href="%1$s" rel="author">%2$s</a>', esc_url( get_author_posts_url( $author_id ) ), $author_name );

	}

	return sprintf(
		'<div %1$s>%2$s</div>',
		$wrapper_attributes,
		$inner_html
	);
}

/**
 * Registers the `gtm/post-author` block on the server.
 */
function gtm_register_block_post_author() {
	gtm_register_block_type( 'post-author', [
		'render_callback' => 'gtm_render_block_post_author',
	] );
}

add_action( 'init', 'gtm_register_block_post_author', 20 );

add_filter( 'gtm.BlockStyleCompiler.gtm/post-author', 'gtm_compile_block_css_post_author', 10, 3 );
function gtm_compile_block_css_post_author( $output, $attributes, $blockName ) {
	$block_style = ['classes' => [], 'style' => []];

	$block_style['classes'][] = 'gtm-block';

	if ( $attributes['enableLink'] && $attributes['enableLinkUnderline'] ) {
		$block_style['classes'][] = 'gtm-has-post-author-link-underline';
	}

	if ( $attributes['enableLink'] && $attributes['enableLinkHoverUnderline'] ) {
		$block_style['classes'][] = 'gtm-has-post-author-link-hover-underline';
	}

	gtm_css_compileCssVar( $block_style, "post-author-icon-spacing", gtm_css_parseSpacingValue( $attributes['iconSpacing'] ) );

	if ( $attributes['enableLink'] ) {
		gtm_css_compileCssVar( $block_style, "post-author-link-color", gtm_css_parseColorValue( $attributes['linkColor'] ) );

		gtm_css_compileCssVar( $block_style, "post-author-link-hover-color", gtm_css_parseColorValue( $attributes['linkHoverColor'] ) );
	}

	if ( $attributes['display'] == 'avatar' ) {
		gtm_css_compileCssVar( $block_style, "post-author-avatar-radius", gtm_css_parseBorderRadiusValue( $attributes['avatarRadius'] ) );

	} else {
		gtm_css_compileCssVar( $block_style, "post-author-icon-size", $attributes['iconSize'] );

		gtm_css_compileCssVar( $block_style, "post-author-icon-color", gtm_css_parseColorValue( $attributes['iconColor'] ) );

		gtm_css_compileCssVar( $block_style, "post-author-icon-hover-color", gtm_css_parseColorValue( $attributes['iconHoverColor'] ) );
	}

	// Apply to output
	$block_style['style'] = ['{{BLOCK}}' => $block_style['style']];

	return [
		'classes' => array_merge( $output['classes'], $block_style['classes'] ),
		'style'   => array_replace_recursive( $output['style'], $block_style['style'] ),
	];
}
