<?php

/**
 * Renders the `gtm/post-date` block on the server.
 *
 * @param array    $attributes Block attributes.
 * @param string   $content    Block default content.
 * @param WP_Block $block      Block instance.
 * @return string Returns the post date for the current post.
 */
function gtm_render_block_post_date( $attr, $content, $block ) {

	if ( ! isset( $block->context['postId'] ) ) {
		return '';
	}

	$post_ID = $block->context['postId'];

	$date = '';
	if ( $attr['format'] == 'time_ago' ) {
		$date = sprintf( esc_html__( '%s ago', 'gutenmate' ), human_time_diff( get_post_time(), current_time( 'U' ) ) );
	} else {
		$date = get_the_date( isset( $attr['format'] ) ? $attr['format'] : '', $post_ID );
	}
	$formatted_date = sprintf( '<time datetime="%2$s">%1$s</time>', $date, get_the_date( 'c', $post_ID ) );

	$wrapper_attributes = get_block_wrapper_attributes( ['class' => ''] );

	$inner_html = '';

	if ( $attr['display'] == 'icon' ) {
		$inner_html .= gtm_icon( ! empty( $attr['icon'] ) ? $attr['icon'] : 'date' );
	}

	if ( empty( $attr['enableLink'] ) ) {
		$inner_html .= $formatted_date;

	} else {
		$inner_html .= sprintf( '<a href="%1$s">%2$s</a>', esc_url( get_the_permalink() ), $formatted_date );

	}

	return sprintf(
		'<div %1$s>%2$s</div>',
		$wrapper_attributes,
		$inner_html
	);
}

/**
 * Registers the `gtm/post-date` block on the server.
 */
function gtm_register_block_post_date() {
	gtm_register_block_type( 'post-date', [
		'render_callback' => 'gtm_render_block_post_date',
	] );
}

add_action( 'init', 'gtm_register_block_post_date', 20 );

add_filter( 'gtm.BlockStyleCompiler.gtm/post-date', 'gtm_compile_block_css_post_date', 10, 3 );
function gtm_compile_block_css_post_date( $output, $attributes, $blockName ) {
	$block_style = ['classes' => [], 'style' => []];

	$block_style['classes'][] = 'gtm-block';

	if ( $attributes['enableLink'] && $attributes['enableLinkUnderline'] ) {
		$block_style['classes'][] = 'gtm-has-post-date-link-underline';
	}

	if ( $attributes['enableLink'] && $attributes['enableLinkHoverUnderline'] ) {
		$block_style['classes'][] = 'gtm-has-post-date-link-hover-underline';
	}

	if ( $attributes['enableLink'] ) {
		gtm_css_compileCssVar( $block_style, "post-date-link-color", gtm_css_parseColorValue( $attributes['linkColor'] ) );

		gtm_css_compileCssVar( $block_style, "post-date-link-hover-color", gtm_css_parseColorValue( $attributes['linkHoverColor'] ) );
	}

	if ( $attributes['display'] !== 'name' ) {
		gtm_css_compileCssVar( $block_style, "post-date-icon-spacing", gtm_css_parseSpacingValue( $attributes['iconSpacing'] ) );

		gtm_css_compileCssVar( $block_style, "post-date-icon-size", $attributes['iconSize'] );

		gtm_css_compileCssVar( $block_style, "post-date-icon-color", gtm_css_parseColorValue( $attributes['iconColor'] ) );

		gtm_css_compileCssVar( $block_style, "post-date-icon-hover-color", gtm_css_parseColorValue( $attributes['iconHoverColor'] ) );
	}

	// Apply to output
	$block_style['style'] = ['{{BLOCK}}' => $block_style['style']];

	return [
		'classes' => array_merge( $output['classes'], $block_style['classes'] ),
		'style'   => array_replace_recursive( $output['style'], $block_style['style'] ),
	];
}
