<?php

/**
 * Renders the `gtm/post-featured-image-caption` block on the server.
 *
 * @param array    $attributes Block attributes.
 * @param string   $content    Block default content.
 * @param WP_Block $block      Block instance.
 * @return string Returns the featured image caption for the current post.
 */
function gtm_render_block_post_featured_image_caption( $attr, $content, $block ) {

	if ( ! isset( $block->context['postId'] ) || ! has_post_thumbnail( $block->context['postId'] ) ) {
		return '';
	}

	$post_ID      = $block->context['postId'];
	$alt_image_id = get_post_meta( $post_ID, 'gtm_alt_featured_image', true );

	$wrapper_attributes = get_block_wrapper_attributes( ['class' => ''] );

	if ( $attr['useAltImage'] && ! empty( $alt_image_id ) ) {
		$media_id = $alt_image_id;
	} else {
		$media_id = get_post_thumbnail_id( $post_ID );
	}

	$media = get_post( $media_id );

	if ( ! $media ) {
		return;
	}

	$display_text = '';

	if ( "caption" == $attr['source'] ) {
		$display_text = $media->post_excerpt;
	} else if ( "title" == $attr['source'] ) {
		$display_text = $media->post_title;
	} else if ( "description" == $attr['source'] ) {
		$display_text = $media->post_content;
	} else if ( "alt" == $attr['source'] ) {
		$display_text = get_post_meta( $media_id, '_wp_attachment_image_alt', true );
	}

	if ( empty( trim( $display_text ) ) ) {
		return;
	}

	$inner_html = '<span>';

	if ( $attr['display'] == 'icon' ) {
		$inner_html .= gtm_icon( ! empty( $attr['icon'] ) ? $attr['icon'] : 'caption' );
	}

	$inner_html .= wp_kses_post( $display_text );
	$inner_html .= '</span>';

	return sprintf(
		'<div %1$s>%2$s</div>',
		$wrapper_attributes,
		$inner_html
	);
}

/**
 * Registers the `gtm/post-featured-image-caption` block on the server.
 */
function gtm_register_block_post_featured_image_caption() {
	gtm_register_block_type( 'post-featured-image-caption', [
		'render_callback' => 'gtm_render_block_post_featured_image_caption',
	] );
}

add_action( 'init', 'gtm_register_block_post_featured_image_caption', 20 );

add_filter( 'gtm.BlockStyleCompiler.gtm/post-featured-image-caption', 'gtm_compile_block_css_post_featured_image_caption', 10, 3 );
function gtm_compile_block_css_post_featured_image_caption( $output, $attributes, $blockName ) {
	$block_style = ['classes' => [], 'style' => []];

	$block_style['classes'][] = 'gtm-block';

	gtm_css_compileCssVarClass( $block_style, "post-featured-image-caption-display", $attributes['display'] );

	gtm_css_compileCssVar( $block_style, "post-featured-image-caption-icon-spacing", gtm_css_parseSpacingValue( $attributes['iconSpacing'] ) );

	if ( $attributes['display'] == 'icon' ) {
		gtm_css_compileCssVar( $block_style, "post-featured-image-caption-icon-size", gtm_css_parseSpacingValue( $attributes['iconSize'] ) );

		gtm_css_compileCssVar( $block_style, "post-featured-image-caption-icon-color", gtm_css_parseColorValue( $attributes['iconColor'] ) );
	}

	// Apply to output
	$block_style['style'] = ['{{BLOCK}}' => $block_style['style']];

	return [
		'classes' => array_merge( $output['classes'], $block_style['classes'] ),
		'style'   => array_replace_recursive( $output['style'], $block_style['style'] ),
	];
}
