<?php

/**
 * Renders the `gtm/post-featured-image-text` block on the server.
 *
 * @param array    $attributes Block attributes.
 * @param string   $content    Block default content.
 * @param WP_Block $block      Block instance.
 * @return string Returns the featured image and text for the current post.
 */
function gtm_render_block_post_featured_image_text( $attr, $content, $block ) {
	$isCover      = 'cover' == ( $attr['display'] ?? '' );
	$hasLink      = ! empty( $attr['linkTo'] );
	$hasThumbnail = has_post_thumbnail( $block->context['postId'] );

	if ( ! isset( $block->context['postId'] ) ) {
		return '';
	}

	$post_ID      = $block->context['postId'];
	$alt_image_id = get_post_meta( $post_ID, 'gtm_alt_featured_image', true );
	$class        = '';

	if ( ! $hasThumbnail ) {
		$class .= ' gtm-has-no-featured-image ';
	}

	$wrapper_attributes = get_block_wrapper_attributes( ['class' => $class] );

	$inner_html = '';

	$inner_html .= '<div class="wp-block-gtm-post-featured-image-text__img">';

	if ( $attr['useAltImage'] && ! empty( $alt_image_id ) ) {
		$inner_html .= wp_get_attachment_image( $alt_image_id, $attr['imageSize'] );
	} else {
		$inner_html .= get_the_post_thumbnail( $post_ID, $attr['imageSize'] );
	}

	$inner_html .= '<div class="wp-block-gtm-post-featured-image-text__overlay"></div>';

	if ( $hasLink ) {
		if ( 'file' == $attr['linkTo'] ) {
			$url = get_the_post_thumbnail_url( $post_ID, 'full' );
		} else {
			$url = get_the_permalink( $post_ID );
		}

		// Do not display link if no url, event no thumbnails was set.
		if ( ! empty( $url ) ) {
			$inner_html .= sprintf( '<a class="wp-block-gtm-post-featured-image-text__link" href="%s" rel="bookmark"></a>', esc_url( $url ) );
		}
	}

	$inner_html .= '</div>'; // .wp-block-gtm-post-featured-image-text__img

	$inner_html .= '<div class="wp-block-gtm-post-featured-image-text__content">';
	$inner_html .= do_blocks( $content );
	$inner_html .= '</div>';

	return sprintf(
		'<div %1$s>%2$s</div>',
		$wrapper_attributes,
		$inner_html
	);
}

/**
 * Registers the `gtm/post-featured-image-text` block on the server.
 */
function gtm_register_block_post_featured_image_text() {
	gtm_register_block_type( 'post-featured-image-text', [
		'render_callback' => 'gtm_render_block_post_featured_image_text',
	] );
}

add_action( 'init', 'gtm_register_block_post_featured_image_text', 20 );

add_filter( 'gtm.BlockStyleCompiler.gtm/post-featured-image-text', 'gtm_compile_block_css_post_featured_image_text', 10, 3 );
function gtm_compile_block_css_post_featured_image_text( $output, $attributes, $blockName ) {
	$block_style = ['classes' => [], 'style' => []];

	$isHorizontal = in_array( $attributes['contentPlacement'], ["left", "right"] );

	$block_style['classes'][] = 'gtm-block';

	if ( $attributes['linkTo'] ) {
		$block_style['classes'][] = "gtm-has-post-featured-image-text-link-to-{$attributes['linkTo']}";
	}

	if ( $attributes['enableCover'] ) {
		$block_style['classes'][] = "gtm-has-post-featured-image-text-image-cover";
	}

	if ( $attributes['imageHoverBlur'] ) {
		$block_style['classes'][] = "gtm-has-post-featured-image-text-hover-blur";
	}

	if ( $attributes['imageHoverGray'] ) {
		$block_style['classes'][] = "gtm-has-post-featured-image-text-hover-gray";
	}

	if ( $attributes['contentPlacement'] ) {
		$block_style['classes'][] = "gtm-has-post-featured-image-text-content-placement-{$attributes['contentPlacement']}";
	}

	gtm_css_compileCssVarClass( $block_style, "post-featured-image-text-hover", $attributes['imageHoverEffect'] );

	if ( $attributes['enableCover'] ) {
		gtm_css_compileCssVar( $block_style, "post-featured-image-text-image-height", $attributes['imageHeight'] );

		gtm_css_compileCssVar( $block_style, "post-featured-image-text-focal", gtm_css_parseFocalPointValue( $attributes['imageFocalPoint'] ) );
	}

	gtm_css_compileCssVar( $block_style, "post-featured-image-text-floating-offset", $attributes['floatingOffset'] );

	gtm_css_compileCssVar( $block_style, "post-featured-image-text-content-padding", gtm_css_parseResponsiveBoxProps( $attributes['contentPadding'] ) );

	if ( $isHorizontal ) {
		gtm_css_compileCssVar( $block_style, "post-featured-image-text-content-size", $attributes['contentSize'] );
	}

	gtm_css_compileCssVar( $block_style, "post-featured-image-text-content-bg", gtm_css_parseColorValue( $attributes['contentBg'] ) );

	gtm_css_compileCssVar( $block_style, "post-featured-image-text-overlay", gtm_css_parseColorValue( $attributes['overlayBg'] ) );

	gtm_css_compileCssVar( $block_style, "post-featured-image-text-overlay-opacity", floatval( $attributes['overlayOpacity'] ?? '' ) / 100 );

	gtm_css_compileCssVar( $block_style, "post-featured-image-text-overlay-blend-mode", $attributes['overlayBlendMode'] );

	gtm_css_compileCssVar( $block_style, "post-featured-image-text-overlay-hover", gtm_css_parseColorValue( $attributes['overlayHoverBg'] ) );

	gtm_css_compileCssVar( $block_style, "post-featured-image-text-overlay-hover-opacity", floatval( $attributes['overlayHoverOpacity'] ?? '' ) / 100 );

	gtm_css_compileCssVar( $block_style, "post-featured-image-text-overlay-hover-blend-mode", $attributes['overlayHoverBlendMode'] );

	// Apply to output
	$block_style['style'] = ['{{BLOCK}}' => $block_style['style']];

	return [
		'classes' => array_merge( $output['classes'], $block_style['classes'] ),
		'style'   => array_replace_recursive( $output['style'], $block_style['style'] ),
	];
}
