<?php

/**
 * Renders the `gtm/post-format-icon` block on the server.
 *
 * @param array    $attributes Block attributes.
 * @param string   $content    Block default content.
 * @param WP_Block $block      Block instance.
 * @return string Returns the post format icon for the current post.
 */
function gtm_render_block_post_format_icon( $attr, $content, $block ) {

	if ( ! isset( $block->context['postId'] ) ) {
		return '';
	}

	$post_ID = $block->context['postId'];
	$icon    = gtm_get_post_format_icon();

	if ( empty( $icon ) ) {
		return;
	}

	$wrapper_attributes = get_block_wrapper_attributes( ['class' => ''] );

	$inner_html = '';
	$inner_html .= gtm_icon( $icon );

	return sprintf(
		'<div %1$s>%2$s</div>',
		$wrapper_attributes,
		$inner_html
	);
}

/**
 * Registers the `gtm/post-format-icon` block on the server.
 */
function gtm_register_block_post_format_icon() {
	gtm_register_block_type( 'post-format-icon', [
		'render_callback' => 'gtm_render_block_post_format_icon',
	] );
}

add_action( 'init', 'gtm_register_block_post_format_icon', 20 );

add_filter( 'gtm.BlockStyleCompiler.gtm/post-format-icon', 'gtm_compile_block_css_post_format_icon', 10, 3 );
function gtm_compile_block_css_post_format_icon( $output, $attributes, $blockName ) {
	$block_style = ['classes' => [], 'style' => []];

	$block_style['classes'][] = 'gtm-block';

	gtm_css_compileCssVar( $block_style, "post-format-icon-icon-size", $attributes['iconSize'] );

	gtm_css_compileCssVar( $block_style, "post-format-icon-icon-color", gtm_css_parseColorValue( $attributes['iconColor'] ) );
	gtm_css_compileCssVar( $block_style, "post-format-icon-icon-bg", gtm_css_parseColorValue( $attributes['iconBg'] ) );
	gtm_css_compileCssVar( $block_style, "post-format-icon-icon-hover-color", gtm_css_parseColorValue( $attributes['iconHoverColor'] ) );
	gtm_css_compileCssVar( $block_style, "post-format-icon-icon-hover-bg", gtm_css_parseColorValue( $attributes['iconHoverBg'] ) );

	// Apply to output
	$block_style['style'] = ['{{BLOCK}}' => $block_style['style']];

	return [
		'classes' => array_merge( $output['classes'], $block_style['classes'] ),
		'style'   => array_replace_recursive( $output['style'], $block_style['style'] ),
	];
}
