<?php

/**
 * Registers the `gtm/review-total-score` block on the server.
 */
function gtm_register_block_review_total_score() {
	gtm_register_block_type( 'review-total-score', [
		'render_callback' => 'gtm_render_block_review_total_score',
	] );
}

function gtm_render_block_review_total_score( $attr, $content, $block ) {
	if ( ! isset( $block->context['gtmReviewTotalScore'] ) ) {
		return '';
	}

	$total_score = $block->context['gtmReviewTotalScore'];

	if ( "percentage" == $attr['design'] ) {
		$total_score_display = number_format_i18n( $total_score, 0 ) . "%";
	} else if ( "points" == $attr['design'] ) {
		$total_score_display = number_format_i18n( $total_score / 10, 1 );
	} else if ( "stars" == $attr['design'] ) {
		$total_score_display = number_format_i18n( $total_score / 20, 1 );
	}

	$inner_html = '';

	if ( in_array( $attr['design'], ['points', 'percentage'] ) ) {
		$donut = gtm_get_review_donut_template();
		$inner_html .= <<<DONUT_TEMPLATE
			<div class="wp-block-gtm-review-total-score__display">
				<div class="wp-block-gtm-review-total-score__number">
					{$total_score_display}
				</div>

				<div class="wp-block-gtm-review-total-score__indicator">
					{$donut}
				</div>
			</div>
		DONUT_TEMPLATE;

	} else if ( "stars" == $attr['design'] ) {
		$inner_html .= <<<STARS_TEMPLATE
			<div class="wp-block-gtm-review-total-score__display">
				<div class="wp-block-gtm-review-total-score__number">
					{$total_score_display}
				</div>
				<div class="wp-block-gtm-review-total-score__indicator">
					<span class="gtm-stars"></span>
				</div>
			</div>
			STARS_TEMPLATE;
	}

	$wrapper_attributes = get_block_wrapper_attributes( ['class' => ''] );

	return sprintf(
		'<div %1$s>%2$s</div>',
		$wrapper_attributes,
		$inner_html
	);
}

function gtm_get_review_donut_template() {
	return <<<DONUT_TEMPLATE
		<div class="gtm-donut">
			<svg
				width="100%"
				height="100%"
				viewBox="0 0 42 42"
				class="gtm-donut-box"
				aria-hidden="true"
				focusable="false"
			>
				<circle
					class="gtm-donut-ring"
					cx="21"
					cy="21"
					r="15.91549430918952"
					fill="transparent"
				></circle>
				<circle
					class="gtm-donut-accent"
					cx="21"
					cy="21"
					r="15.91549430918952"
					fill="transparent"
				></circle>
			</svg>
		</div>
	DONUT_TEMPLATE;
}

add_action( 'init', 'gtm_register_block_review_total_score', 20 );

add_filter( 'gtm.BlockStyleCompiler.gtm/review-total-score', 'gtm_compile_block_css_review_total_score', 10, 3 );
function gtm_compile_block_css_review_total_score( $output, $attributes, $blockName ) {
	$block_style = ['classes' => [], 'style' => []];

	$hasStars = in_array( $attributes['design'], ['stars'] );

	$block_style['classes'][] = 'gtm-block';
	$block_style['classes'][] = 'gtm-is-review-total-score-' . $attributes['design'];

	gtm_css_compileCssVar( $block_style, "total-score-content-justify", gtm_css_parseFlexAlignValue( $attributes['contentJustify'] ) );

	$context = GTM_Block_Context::current();
	if ( isset( $context['gtmReviewTotalScore'] ) ) {
		gtm_css_compileCssVar( $block_style, "total-score-value", $context['gtmReviewTotalScore'] );
	}

	if ( $hasStars ) {
		gtm_css_compileCssVar( $block_style, "total-score-star-size", $attributes['starSize'] );

		gtm_css_compileCssVar( $block_style, "total-score-indicator-spacing", gtm_css_parseSpacingValue( $attributes['indicatorSpacing'] ) );
	} else {
		gtm_css_compileCssVar( $block_style, "total-score-circle-stroke-width", $attributes['circleStrokeWidth'] ?? null );

		gtm_css_compileCssVar( $block_style, "total-score-circle-width", $attributes['circleWidth'] );

	}

	gtm_css_compileCssVar( $block_style, "total-score-indicator-bg", gtm_css_parseColorValue( $attributes['indicatorBg'] ) );

	gtm_css_compileCssVar( $block_style, "total-score-indicator-color", gtm_css_parseColorValue( $attributes['indicatorColor'] ) );

	gtm_css_compileCssVar( $block_style, "total-score-number-color", gtm_css_parseColorValue( $attributes['scoreColor'] ) );

	gtm_css_compileCssVar( $block_style, "total-score-number-typography", gtm_css_parseTypographyProps( $attributes['scoreTypography'] ) );

	// Apply to output
	$block_style['style'] = ['{{BLOCK}}' => $block_style['style']];

	return [
		'classes' => array_merge( $output['classes'], $block_style['classes'] ),
		'style'   => array_replace_recursive( $output['style'], $block_style['style'] ),
	];
}
