<?php

defined( 'GTM_REQUIRE_GUTENBERG_DISMISS_KEY' ) || define( 'GTM_REQUIRE_GUTENBERG_DISMISS_KEY', 'gtm_require_gutenberg_dismiss' );

/*//////////////////////////////////////
// Check version
// https://developer.wordpress.org/block-editor/contributors/versions-in-wordpress/
//////////////////////////////////////*/

add_action( 'init', 'gtm_require_gutenberg_check_version' );
function gtm_require_gutenberg_check_version() {
	global $wp_version;
	if ( is_admin() ) {
		$is_require_gutenberg    = true;
		$local_gutenberg_version = defined( 'GUTENBERG_VERSION' ) ? GUTENBERG_VERSION : false;

		if ( ! get_option( GTM_REQUIRE_GUTENBERG_DISMISS_KEY, false ) ) {
			if ( $local_gutenberg_version && version_compare( $local_gutenberg_version, '12.0.0', '>=' ) ) {
				$is_require_gutenberg = false;

			} else if ( version_compare( $wp_version, '6.0', '>=' ) ) {
				$is_require_gutenberg = false;
			}

			if ( $is_require_gutenberg ) {
				add_action( 'admin_notices', 'gtm_require_gutenberg_notice' );
				add_action( 'admin_enqueue_scripts', 'gtm_require_gutenberg_scripts' );
			}
		}
	}
}

function gtm_require_gutenberg_scripts() {
	wp_enqueue_script(
		'gtm-require-gutenberg-admin-notice',
		GTM_URL . 'assets/js/require-gutenberg-admin-notice.js'
	);
}

add_action( 'wp_ajax_gtm_dismiss_require_gutenberg_notice', 'gtm_require_gutenberg_dismiss_notice' );
function gtm_require_gutenberg_dismiss_notice() {
	update_option( GTM_REQUIRE_GUTENBERG_DISMISS_KEY, true );
}

function gtm_require_gutenberg_notice() {
	?>
	<div id="gtm-require-gutenberg-admin-notice" class="notice notice-warning is-dismissible">
    	<p><?php echo wp_kses_post(
		sprintf(
			/* pass to wp_kses_post() */ __( 'Gutenberg plugin (version 12.0.0 or later) is required for running Gutenmate plugin smoothly. Please install by clicking <a href="%s" class="thickbox open-plugin-details-modal">this link</a>.', 'gutenmate' ), esc_url( admin_url( 'plugin-install.php?tab=plugin-information&amp;plugin=gutenberg&amp;TB_iframe=true&amp;width=600&amp;height=550' ) )
		)
	); ?></p>
	</div>
	<?php
}

/*//////////////////////////////////////
// Clear dismiss flag after activated
//////////////////////////////////////*/

function gtm_require_gutenberg_clear_dismiss() {
	delete_option( GTM_REQUIRE_GUTENBERG_DISMISS_KEY );
}

register_activation_hook( GTM_BASE, 'gtm_require_gutenberg_clear_dismiss' );