<?php

/*//////////////////////////////////////
// Icon
//////////////////////////////////////*/

if ( ! function_exists( 'gtm_get_default_icons' ) ) {
	function gtm_get_default_icons() {
		$theme_icons = get_theme_support( 'gtm_icons' );
		$add_icons   = [];

		if ( is_array( $theme_icons ) && ! empty( $theme_icons[0] ) ) {
			$add_icons = $theme_icons[0];
		}

		return wp_parse_args( $add_icons, [
			'arrow-left'      => 'gtm-basic-icon-chevron-left',
			'arrow-right'     => 'gtm-basic-icon-chevron-right',
			'arrow-up'        => 'gtm-basic-icon-chevron-up',
			'arrow-down'      => 'gtm-basic-icon-chevron-down',
			'audio'           => 'gtm-basic-icon-headphones',
			'author'          => 'gtm-basic-icon-user',
			'back-to-top'     => 'gtm-basic-icon-chevron-up',
			'caption'         => 'gtm-basic-icon-image',
			'cart'            => 'gtm-basic-icon-cart-shopping',
			'close'           => 'gtm-basic-icon-xmark',
			'comments'        => 'gtm-basic-icon-comment',
			'date'            => 'gtm-basic-icon-calendar',
			'edit'            => 'gtm-basic-icon-pen',
			'gallery'         => 'gtm-basic-icon-images',
			'home'            => 'gtm-basic-icon-house',
			'hot'             => 'gtm-basic-icon-fire',
			'image'           => 'gtm-basic-icon-image',
			'like'            => 'gtm-basic-icon-heart',
			'link'            => 'gtm-basic-icon-link',
			'menu'            => 'gtm-basic-icon-bars',
			'random'          => 'gtm-basic-icon-random',
			'read-more-arrow' => 'gtm-basic-icon-arrow-right',
			'read-more'       => 'gtm-basic-icon-book-open',
			'review'          => 'gtm-basic-icon-star',
			'search'          => 'gtm-basic-icon-magnifying-glass',
			'share'           => 'gtm-basic-icon-share-nodes',
			'standard'        => 'gtm-basic-icon-newspaper',
			'submenu'         => 'gtm-basic-icon-chevron-right',
			'time'            => 'gtm-basic-icon-clock',
			'user'            => 'gtm-basic-icon-user',
			'video'           => 'gtm-basic-icon-play',
			'views'           => 'gtm-basic-icon-eye',
			'facebook'        => 'gtm-basic-icon-facebook-f',
			'twitter'         => 'gtm-basic-icon-twitter',
			'linkedin'        => 'gtm-basic-icon-linkedin-in',
			'mix'             => 'gtm-basic-icon-mix',
			'pinterest'       => 'gtm-basic-icon-pinterest-p',
			'reddit'          => 'gtm-basic-icon-reddit',
			'buffer'          => 'gtm-basic-icon-buffer',
			'vk'              => 'gtm-basic-icon-vk',
			'pocket'          => 'gtm-basic-icon-pocket',
			'whatsapp'        => 'gtm-basic-icon-whatsapp',
			'telegram'        => 'gtm-basic-icon-telegram',
			'viber'           => 'gtm-basic-icon-viber',
			'email'           => 'gtm-basic-icon-envelope',
			'print'           => 'gtm-basic-icon-print',
		] );
	}
}
if ( ! function_exists( 'gtm_icon' ) ) {
	function gtm_icon( $label ) {
		$icons = gtm_get_default_icons();

		if ( isset( $icons[$label] ) ) {
			$icon_class = $icons[$label];
		} else {
			// Use as class, for creating icon tag only
			$icon_class = $label;
		}

		if ( ! empty( $icon_class ) ) {
			return '<i class="gtm-icon ' . esc_attr( $icon_class ) . '"  aria-hidden="true"></i>';
		}
	}
}

if ( ! function_exists( 'gtm_the_icon' ) ) {
	function gtm_the_icon( $label ) {
		echo gtm_icon( $label ); // WPCS: XSS ok
	}
}

/*//////////////////////////////////////
// Tooltip
//////////////////////////////////////*/

if ( ! function_exists( 'gtm_tooltip' ) ) {
	function gtm_tooltip( $text = '', $arialabel = true ) {
		$output = '';
		if ( ! empty( $text ) ) {
			$output .= sprintf( ' data-tippy-content="%s"', esc_attr( $text ) );

			// Aria label
			if ( $arialabel === true ) {
				$output .= sprintf( ' aria-label="%s"', esc_attr( $text ) );

			} else if ( ! empty( $arialabel ) ) {
				$output .= sprintf( ' aria-label="%s"', esc_attr( $arialabel ) );

			}
		}

		return $output;
	}
}

if ( ! function_exists( 'gtm_the_tooltip' ) ) {
	function gtm_the_tooltip( $text = '', $arialabel = true ) {
		echo gtm_tooltip( $text, $arialabel ); // WPCS: XSS OK.
	}
}
