<?php

/*//////////////////////////////////////
// Load Modules
//////////////////////////////////////*/

include_once GTM_DIR . 'settings/settings.php';
include_once GTM_DIR . 'settings/settings-page.php';
include_once GTM_DIR . 'settings/user-profile-page.php';
include_once GTM_DIR . 'lib/load.php';
include_once GTM_DIR . 'block-library/blocks.php';
include_once GTM_DIR . 'block-extensions/header-sticky.php';
include_once GTM_DIR . 'block-extensions/core-blocks.php';
include_once GTM_DIR . 'block-extensions/core-image.php';
include_once GTM_DIR . 'block-extensions/core-query.php';
include_once GTM_DIR . 'block-extensions/core-query-pagination-numbers.php';
include_once GTM_DIR . 'block-extensions/core-query-pagination-next.php';
include_once GTM_DIR . 'block-extensions/core-query-pagination-previous.php';
include_once GTM_DIR . 'block-extensions/core-quote.php';
include_once GTM_DIR . 'block-extensions/core-navigation.php';
include_once GTM_DIR . 'block-extensions/core-site-logo.php';
include_once GTM_DIR . 'block-extensions/post-options.php';
include_once GTM_DIR . 'block-supports/block-visibility.php';
include_once GTM_DIR . 'block-supports/flexbox-child.php';
include_once GTM_DIR . 'block-supports/block-style.php';
include_once GTM_DIR . 'block-supports/block-props.php';
include_once GTM_DIR . 'block-supports/use-web-fonts.php';
include_once GTM_DIR . 'block-supports/footer-content.php';

include_once GTM_DIR . 'block-extensions/block-printing.php';

/*//////////////////////////////////////
// Load Plugin Text Domain
//////////////////////////////////////*/

add_action( 'plugins_loaded', 'gtm_load_textdomain' );
function gtm_load_textdomain() {
	load_plugin_textdomain( 'gutenmate', FALSE, GTM_DIR . '/languages' );
}

/*//////////////////////////////////////
// Register assets
//////////////////////////////////////*/

add_action( 'init', 'gtm_setup_assets' );
function gtm_setup_assets() {
	wp_register_style( 'gutenmate-plugin', GTM_URL . 'assets/css/plugin.css', [], GTM_VERSION );
}

/**
 * Locate core template for overriden from child theme
 * Usage: gtm_locate_template( 'template-parts/posts/post-box.php' );
 */

function gtm_locate_template( $file ) {
	$theme_file = get_theme_file_path( $file );

	if ( file_exists( $theme_file ) ) {
		return $theme_file;
	} else {
		return GTM_DIR . $file;
	}
}

/*//////////////////////////////////////
// Register supported theme features
//////////////////////////////////////*/

/**
 * Theme feature: Image sizes
 */

add_action( 'setup_theme', 'gtm_register_theme_feature_image_sizes', 0 );
function gtm_register_theme_feature_image_sizes() {
	register_theme_feature( 'gutenmate-image-sizes', [
		'type'         => 'array',
		'description'  => esc_html__( 'Image sizes to be registered. These image sizes can be managed in gutenmate.', 'gutenmate' ),
		'show_in_rest' => [
			'schema' => [
				'type'  => 'array',
				'items' => [
					'type'       => 'object',
					'properties' => [
						'enable' => ["type" => 'boolean'],
						'name'   => ["type" => 'string'],
						'width'  => ["type" => 'number'],
						'height' => ["type" => 'number'],
						'crop'   => ["type" => 'boolean'],
						'cropX'  => ["type" => 'string'],
						'cropY'  => ["type" => 'string'],
					],
				],
			],
		],
	] );
}

/**
 * Theme feature: Spacing
 * Example CSS Output:
 * --gtm--space--3xl: 72px;
 * --gtm--space--4xl: 80px;
 */

add_action( 'setup_theme', 'gtm_register_theme_feature_spacing', 0 );
function gtm_register_theme_feature_spacing() {
	register_theme_feature( 'gutenmate-spacing', [
		'type'         => 'array',
		'description'  => esc_html__( 'Image sizes to be registered. These image sizes can be managed in gutenmate.', 'gutenmate' ),
		'show_in_rest' => [
			'schema' => [
				'type'  => 'array',
				'items' => [
					'type'       => 'object',
					'properties' => [
						'name' => ["type" => 'string'],
						'slug' => ["type" => 'string'],
						'size' => ["type" => 'string'],
					],
				],
			],
		],
	] );
}

/**
 * Theme feature: Font families
 * Example CSS Output:
 * --gtm--font-family--headline: 'Oswald'
 */

add_action( 'setup_theme', 'gtm_register_theme_feature_font_families', 0 );
function gtm_register_theme_feature_font_families() {
	register_theme_feature( 'gutenmate-font-families', [
		'type'         => 'array',
		'description'  => esc_html__( 'Font families to be registered with automatic loading google fonts.', 'gutenmate' ),
		'show_in_rest' => [
			'schema' => [
				'type'  => 'array',
				'items' => [
					'type'       => 'object',
					'properties' => [
						'name'              => ["type" => 'string'],
						'slug'              => ["type" => 'string'],
						'fontFamily'        => ["type" => 'string'],
						'preloadFontWeight' => [
							"type"        => 'string',
							'description' => esc_html__( 'Font weight to be preloaded. Use comma for multiple weights. Ex. "300,400,400i".', 'gutenmate' ),
						],
					],
				],
			],
		],
	] );
}

/**
 * Theme feature: Typography
 * Example CSS Output:
 * --gtm--typography--heading-1--font-family: 'Oswald';
 * --gtm--typography--heading-2x--font-size: '30px';
 */

add_action( 'setup_theme', 'gtm_register_theme_feature_typography', 0 );
function gtm_register_theme_feature_typography() {
	register_theme_feature( 'gutenmate-typography', [
		'type'         => 'array',
		'description'  => esc_html__( 'Typography preset to be registered.', 'gutenmate' ),
		'show_in_rest' => [
			'schema' => [
				'type'  => 'array',
				'items' => [
					'type'       => 'object',
					'properties' => [
						'name'           => ["type" => 'string'],
						'slug'           => ["type" => 'string'],
						'font-family'    => ["type" => 'string'],
						/* Font weight and style, For italic use '400i' */
						'font-weight'    => ["type" => 'string'],
						'font-size'      => [
							"type"       => ['string', 'object'],
							'properties' => [
								'sm' => ["type" => 'string'],
								'md' => ["type" => 'string'],
								'lg' => ["type" => 'string'],
							],
						],
						'line-height'    => [
							"type"       => ['string', 'object'],
							'properties' => [
								'sm' => ["type" => 'string'],
								'md' => ["type" => 'string'],
								'lg' => ["type" => 'string'],
							],
						],
						'letter-spacing' => [
							"type"       => ['string', 'object'],
							'properties' => [
								'sm' => ["type" => 'string'],
								'md' => ["type" => 'string'],
								'lg' => ["type" => 'string'],
							],
						],
						'text-transform' => ["type" => 'string'],
					],
				],
			],
		],
	] );
}
